<?php 
	
	global $mowafutility,$mowaf_dirname,$Mo2fdbQueries;

	if ( current_user_can( 'manage_options' ) and isset( $_POST['option'] ) )
	{
		$option = sanitize_text_field(trim($_POST['option']));
		switch($option)
		{
			case "mowaf_register_customer":
				mowaf_register_customer();																	   break;
			case "mowaf_verify_customer":
				mowaf_verify_customer();																	   break;
			case "mowaf_cancel":
				mowaf_revert_back_registration();																   break;
			case "mowaf_reset_password":
				mowaf_reset_password(); 																		  	   break;
		    case "mowaf_goto_verifycustomer":
		        mowaf_goto_sign_in_page();   break;
		}
	} 

	$user = wp_get_current_user();
	$mo2f_current_registration_status = get_site_option('mo_2factor_user_registration_status');
	
	if ((get_site_option ( 'mo_wpns_verify_customer' ) == 'true' || (get_site_option('mo2f_email') && !get_site_option('mo2f_customerKey'))) && $mo2f_current_registration_status == "MO_2_FACTOR_VERIFY_CUSTOMER")
	{
		$admin_email = get_site_option('mo2f_email') ? get_site_option('mo2f_email') : "";		
		include $mowaf_dirname . 'views'.DIRECTORY_SEPARATOR.'account'.DIRECTORY_SEPARATOR.'login.php';
	}
	else if (! $mowafutility->icr()) 
	{
		delete_site_option ( 'password_mismatch' );
		update_site_option ( 'mo_wpns_new_registration', 'true' );
        update_site_option ( 'mo_2factor_user_registration_status', 'REGISTRATION_STARTED'  );
		include $mowaf_dirname . 'views'.DIRECTORY_SEPARATOR.'account'.DIRECTORY_SEPARATOR.'register.php';
	} 
	else
	{
		$email = get_site_option('mo2f_email');
		$key   = get_site_option('mo2f_customerKey');
		$api   = get_site_option('mo2f_api_key');
		$token = get_site_option('mo2f_customer_token');
		include $mowaf_dirname . 'views'.DIRECTORY_SEPARATOR.'account'.DIRECTORY_SEPARATOR.'profile.php';
	}


	function mowaf_register_customer()
	{
		$nonce = sanitize_text_field($_POST['nonce']);
	   		if ( ! wp_verify_nonce( $nonce, 'mowaf-account-nonce' ) ){
	   			do_action('mowaf_show_message',MOWAF_Messages::showMessage('NONCE_ERROR'),'ERROR');
	   			return;
	   		}
		global $mowafutility;
		$user            = wp_get_current_user();
		$email 			 = sanitize_email($_POST['email']);
		$company 		 = $_SERVER["SERVER_NAME"];

		$password 		 = sanitize_text_field($_POST['password']);
		$confirmPassword = sanitize_text_field($_POST['confirmPassword']);

		if( strlen( $password ) < 6 || strlen( $confirmPassword ) < 6)
		{
			do_action('mowaf_show_message',MOWAF_Messages::showMessage('PASS_LENGTH'),'ERROR');
			return;
		}
		
		if( $password != $confirmPassword )
		{
			do_action('mowaf_show_message',MOWAF_Messages::showMessage('PASS_MISMATCH'),'ERROR');
			return;
		}
		if( MOWAF_Utility::check_empty_or_null( $email ) || MOWAF_Utility::check_empty_or_null( $password ) 
			|| MOWAF_Utility::check_empty_or_null( $confirmPassword ) ) 
		{
			do_action('mowaf_show_message',MOWAF_Messages::showMessage('REQUIRED_FIELDS'),'ERROR');
			return;
		} 

		update_site_option( 'mo2f_email', $email );
		
		update_site_option( 'mo_wpns_company'    , $company );
		
		update_site_option( 'mo_wpns_password'   , $password );

		$customer = new MOWAF_cURL();
		$content  = json_decode($customer->check_customer($email), true);
		switch ($content['status'])
		{
			case 'CUSTOMER_NOT_FOUND':
			      $customerKey = json_decode($customer->create_customer($email, $company, $password, $phone = '', $first_name = '', $last_name = ''), true);
				  
			   if(strcasecmp($customerKey['status'], 'SUCCESS') == 0) 
				{
					mowaf_save_success_customer_config($email, $customerKey['id'], $customerKey['apiKey'], $customerKey['token'], $customerKey['appSecret']);
					mowaf_get_current_customer($email,$password);
				}
				
				break;
			default:
				mowaf_get_current_customer($email,$password);
				break;
		}

	}


   function mowaf_goto_sign_in_page(){  	
		$nonce = sanitize_text_field($_POST['nonce']);
	   		if ( ! wp_verify_nonce( $nonce, 'mowaf-account-nonce' ) ){
	   			do_action('mowaf_show_message',MOWAF_Messages::showMessage('NONCE_ERROR'),'ERROR');
	   			return;
	   		}
   	   update_site_option('mo_wpns_verify_customer','true');
	   update_site_option('mo_2factor_user_registration_status','MO_2_FACTOR_VERIFY_CUSTOMER'  );
   }

	function mowaf_revert_back_registration()
	{		
		$nonce = sanitize_text_field($_POST['nonce']);
	   		if ( ! wp_verify_nonce( $nonce, 'mowaf-account-nonce' ) ){
	   			do_action('mowaf_show_message',MOWAF_Messages::showMessage('NONCE_ERROR'),'ERROR');
	   			return;
	   		}
		delete_site_option('mo2f_email');
		delete_site_option('mo_wpns_registration_status');
		delete_site_option('mo_wpns_verify_customer');
		update_site_option( 'mo_2factor_user_registration_status', '' );
	}


	function mowaf_reset_password()
	{
		$nonce = sanitize_text_field($_POST['nonce']);
	   		if ( ! wp_verify_nonce( $nonce, 'mowaf-account-nonce' ) ){
	   			do_action('mowaf_show_message',MOWAF_Messages::showMessage('NONCE_ERROR'),'ERROR');
	   			return;
	   		}
		$customer = new MOWAF_cURL();
		$forgot_password_response = json_decode($customer->mo_wpns_forgot_password());
		if($forgot_password_response->status == 'SUCCESS')
			do_action('mowaf_show_message',MOWAF_Messages::showMessage('RESET_PASS'),'SUCCESS');
	}

	function mowaf_verify_customer()
	{		
		$nonce = sanitize_text_field($_POST['nonce']);
	   		if ( ! wp_verify_nonce( $nonce, 'mowaf-account-nonce' ) ){
	   			do_action('mowaf_show_message',MOWAF_Messages::showMessage('NONCE_ERROR'),'ERROR');
	   			return;
	   		}
		global $mowafutility;
		$email 	  = sanitize_email( $_POST['email'] );
		$password = sanitize_text_field( $_POST['password'] );

		if( $mowafutility->check_empty_or_null( $email ) || $mowafutility->check_empty_or_null( $password ) ) 
		{
			do_action('mowaf_show_message',MOWAF_Messages::showMessage('REQUIRED_FIELDS'),'ERROR');
			return;
		} 
		mowaf_get_current_customer($email,$password);
	}

	function mowaf_get_current_customer($email,$password)
	{
		$user   = wp_get_current_user();
		$customer 	 = new MOWAF_cURL();
		$content     = $customer->get_customer_key($email, $password);
		$customerKey = json_decode($content, true);
		if(json_last_error() == JSON_ERROR_NONE) 
		{
			if(isset($customerKey['phone'])){
				update_site_option( 'mo_wpns_admin_phone', $customerKey['phone'] );
			}
			update_site_option('mo2f_email',$email);
			mowaf_save_success_customer_config($email, $customerKey['id'], $customerKey['apiKey'], $customerKey['token'], $customerKey['appSecret']);
			do_action('mowaf_show_message',MOWAF_Messages::showMessage('REG_SUCCESS'),'SUCCESS');
		} 
		else 
		{
			update_site_option( 'mo_2factor_user_registration_status', 'MO_2_FACTOR_VERIFY_CUSTOMER' );
			update_site_option('mo_wpns_verify_customer', 'true');
			delete_site_option('mo_wpns_new_registration');
			do_action('mowaf_show_message',MOWAF_Messages::showMessage('ACCOUNT_EXISTS'),'ERROR');
		}
	}
	
	function mowaf_save_success_customer_config($email, $id, $apiKey, $token, $appSecret)
	{

		$user   = wp_get_current_user();
		update_site_option( 'mo2f_customerKey'            , $id 		  );
		update_site_option( 'mo2f_api_key'                , $apiKey    );
		update_site_option( 'mo2f_customer_token'		 , $token 	  );
		update_site_option( 'mo2f_app_secret'			 , $appSecret );
		update_site_option( 'mo_wpns_enable_log_requests' , true 	  );
		update_site_option( 'mo2f_miniorange_admin'       , $user->ID  );
		update_site_option( 'mo_2factor_admin_registration_status', 'MO_2_FACTOR_CUSTOMER_REGISTERED_SUCCESS' );
		delete_site_option( 'mo_wpns_verify_customer'				  );
		delete_site_option( 'mo_wpns_registration_status'			  );
		delete_site_option( 'mo_wpns_password'						  );
	}