<?php

global $mowafutility,$mowaf_dirname,$uploaddir;

if(current_user_can( 'manage_options' )  && isset($_POST['option']))
{		
	$option = sanitize_text_field ($_POST['option']);
	switch($option)
	{
		case "mowaf_content_protection":
			mowaf_handle_content_protection();					break;
		case "mowaf_enable_comment_spam_blocking":
			mowaf_handle_comment_spam_blocking();				break;
		case "mowaf_enable_comment_recaptcha":
			mowaf_handle_comment_recaptcha();					break;
		case "mowaf_comment_recaptcha_settings":
			mowaf_save_comment_recaptcha();						break;		
	}
}


$protect_wp_config 		= get_site_option('mo2f_protect_wp_config') 		   		 ? "checked" : "";
$protect_wp_uploads		= get_site_option('mo2f_prevent_directory_browsing') 	 ? "checked" : "";
$disable_file_editing	= get_site_option('mo2f_disable_file_editing') 	   		 ? "checked" : ""; 
$comment_spam_protect	= get_site_option('mo_wpns_enable_comment_spam_blocking') ? "checked" : "";
$enable_recaptcha 		= get_site_option('mo_wpns_enable_comment_recaptcha')     ? "checked" : "";
$htaccess_file 			= get_site_option('mo2f_htaccess_file') 					 ? "checked" : "";
$restAPI 				= get_site_option('mo2f_restrict_restAPI') 				 ? "checked" : "";
$test_recaptcha_url		= "";
$wp_uploads 	   		= $uploaddir['baseurl'];
$restAPI_link 			= rest_url().'wp/v2/users';
$restApiPlugin			= 'https://www.wordpress.org/plugins/wp-rest-api-authentication';
if($enable_recaptcha)
{
	$test_recaptcha_url	= add_query_arg( array('option'=>'testrecaptchaconfig'), $_SERVER['REQUEST_URI'] );	
	$captcha_site_key	= get_site_option('mo_wpns_recaptcha_site_key'  );
	$captcha_secret_key = get_site_option('mo_wpns_recaptcha_secret_key');
}

include $mowaf_dirname . 'views'.DIRECTORY_SEPARATOR.'content-protection.php';

function mowaf_handle_content_protection()
{
		$nonce = sanitize_text_field ($_POST['nonce']);
	   		if ( ! wp_verify_nonce( $nonce, 'mowaf-content-protection-nonce' ) ){
		do_action('mowaf_show_message',MOWAF_Messages::showMessage('NONCE_ERROR'),'ERROR');
	   			return;
	   		}
	isset($_POST['protect_wp_config']) 			? update_site_option('mo2f_protect_wp_config'		 , sanitize_text_field ($_POST['protect_wp_config']))			: update_site_option('mo2f_protect_wp_config'			,0);
	isset($_POST['prevent_directory_browsing']) ? update_site_option('mo2f_prevent_directory_browsing',
		sanitize_text_field ( $_POST['prevent_directory_browsing'])) : update_site_option('mo2f_prevent_directory_browsing',0);
	isset($_POST['disable_file_editing']) 		? update_site_option('mo2f_disable_file_editing'		 ,sanitize_text_field ( $_POST['disable_file_editing']))	   : update_site_option('mo2f_disable_file_editing'		,0);
	isset($_POST['mo2f_htaccess_file']) 		? update_site_option('mo2f_htaccess_file'			 , sanitize_text_field ($_POST['mo2f_htaccess_file']))	        : update_site_option('mo2f_htaccess_file',0);
	if(isset($_POST['restrictAPI'])){
		update_site_option('mo2f_restrict_restAPI', 1);	
	}
	else{
		update_site_option('mo2f_restrict_restAPI',0);	
	}
					
	$mo_wpns_htaccess_handler = new MOWAF_Handler();
	$mo_wpns_htaccess_handler->update_htaccess_configuration();
	do_action('mowaf_show_message',MOWAF_Messages::showMessage('CONTENT_PROTECTION_ENABLED'),'SUCCESS');
}

function mowaf_handle_comment_spam_blocking()
{
		$nonce = sanitize_text_field ($_POST['nonce']);
	   		if ( ! wp_verify_nonce( $nonce, 'mowaf-content-protection-nonce' ) ){
		do_action('mowaf_show_message',MOWAF_Messages::showMessage('NONCE_ERROR'),'ERROR');
	   			return;
	   		}
	$enable  = isset($_POST['mo_wpns_enable_comment_spam_blocking']) ? true : false;
	update_site_option('mo_wpns_enable_comment_spam_blocking', $enable);
	if($enable)
		do_action('mowaf_show_message',MOWAF_Messages::showMessage('CONTENT_SPAM_BLOCKING'),'SUCCESS');
	else
		do_action('mowaf_show_message',MOWAF_Messages::showMessage('CONTENT_SPAM_BLOCKING_DISABLED'),'ERROR');
}

function mowaf_handle_comment_recaptcha()
{
		$nonce = sanitize_text_field ($_POST['nonce']);
	   		if ( ! wp_verify_nonce( $nonce, 'mowaf-content-protection-nonce' ) ){
		do_action('mowaf_show_message',MOWAF_Messages::showMessage('NONCE_ERROR'),'ERROR');
	   			return;
	   		}
	$enable  = isset($_POST['mo_wpns_enable_comment_recaptcha']) ? true : false;
	update_site_option('mo_wpns_enable_comment_recaptcha', $enable);
	if($enable)
		do_action('mowaf_show_message',MOWAF_Messages::showMessage('CONTENT_RECAPTCHA'),'SUCCESS');
	else
		do_action('mowaf_show_message',MOWAF_Messages::showMessage('CONTENT_RECAPTCHA_DISABLED'),'ERROR');
}

function mowaf_save_comment_recaptcha(){
	$nonce =sanitize_text_field ( $_POST['nonce']);
	   		if ( ! wp_verify_nonce( $nonce, 'mowaf-content-protection-nonce' ) ){
		do_action('mowaf_show_message',MOWAF_Messages::showMessage('NONCE_ERROR'),'ERROR');
	   			return;
	   		}
	update_site_option('mo_wpns_recaptcha_site_key'   , sanitize_text_field ($_POST['mo_wpns_recaptcha_site_key'  ]));
	update_site_option('mo_wpns_recaptcha_secret_key' , sanitize_text_field ($_POST['mo_wpns_recaptcha_secret_key']));
	do_action('mowaf_show_message',MOWAF_Messages::showMessage('RECAPTCHA_ENABLED'),'SUCCESS');
}