<?php
class MOWAF_ajax_dashboard
{
	function __construct(){
		add_action( 'admin_init'  , array( $this, 'mowaf_switch_functions' ) );
	}

	public function mowaf_switch_functions(){
		global $mowaf_home_path;
		$mowaf_home_path= get_home_path();
		if(isset($_POST) && isset($_POST['option'])){
			
			$option = sanitize_text_field ($_POST['option']);
			$tab_count= get_site_option('mowaf_tab_count', 0);
			
			if($tab_count == 4)
				update_site_option('mo_2f_switch_all', 1);
			else if($tab_count == 0)
				update_site_option('mo_2f_switch_all', 0);
			
			switch($option)
			{
				case "tab_all_switch":
					$this->mowaf_handle_all_enable();
					break;
				case "tab_login_switch":
					$this->mowaf_handle_login_enable();
					break;
				case "tab_block_switch":
					$this->mowaf_handle_block_enable();
					break;
				case "tab_report_switch":
					$this->mowaf_handle_report_enable();
					break;
				case "tab_notif_switch":
					$this->mowaf_handle_notif_enable();
					break;
			}
		}
	}

	public function mowaf_handle_all_enable(){
		$nonce = sanitize_text_field ($_POST['nonce']);
	   	if( ! wp_verify_nonce( $nonce, 'mowaf-switch-functions-nonce' ) ){
		do_action('mowaf_show_message',MOWAF_Messages::showMessage('NONCE_ERROR'),'ERROR');
	   		return;
	   	}
		$POSTED = isset($_POST['switch_val']);
		$POSTED=sanitize_text_field($POSTED);
		$this->mowaf_handle_login_enable($POSTED);
		$this->mowaf_handle_block_enable($POSTED);
		$this->mowaf_handle_report_enable($POSTED);
		$this->mowaf_handle_notif_enable($POSTED);
		if($POSTED){
			update_site_option('mo_2f_switch_all',1);
			update_site_option('mowaf_tab_count', 4);
			do_action('mowaf_show_message',MOWAF_Messages::showMessage('ALL_ENABLED'),'SUCCESS');
		}
		else{
			update_site_option('mo_2f_switch_all', 0);
			update_site_option('mowaf_tab_count', 0);
			do_action('mowaf_show_message',MOWAF_Messages::showMessage('ALL_DISABLED'),'ERROR');
		}
	}

	public function mowaf_handle_login_enable(){
		$nonce = sanitize_text_field ($_POST['nonce']);
	   		if ( ! wp_verify_nonce( $nonce, 'mowaf-switch-functions-nonce' ) ){
		do_action('mowaf_show_message',MOWAF_Messages::showMessage('NONCE_ERROR'),'ERROR');
	   			return;
	   		}
		$POSTED = isset($_POST['switch_val']);
		$POSTED=sanitize_text_field($POSTED);
		if($POSTED){
			update_site_option('mo_2f_switch_loginspam', 1);
			update_site_option('mowaf_tab_count', get_site_option('mowaf_tab_count')+1);
			if(sanitize_text_field ($_POST['option']) == 'tab_login_switch')
				do_action('mowaf_show_message',MOWAF_Messages::showMessage('LOGIN_ENABLE'),'SUCCESS');
		}
		else{
			update_site_option('mo_2f_switch_loginspam', 0);
			update_site_option('mowaf_tab_count', get_site_option('mowaf_tab_count')-1);
			update_site_option('mo2f_enable_brute_force', false);
			update_site_option('mo_wpns_activate_recaptcha', false);
			update_site_option('mo_wpns_activate_recaptcha_for_login', false);
			update_site_option('mo_wpns_activate_recaptcha_for_woocommerce_login', false);
			update_site_option('mo_wpns_activate_recaptcha_for_registration', false);
			update_site_option('mo_wpns_activate_recaptcha_for_woocommerce_registration', false);
			update_site_option('mo2f_enforce_strong_passswords', 0);
			update_site_option('mo_wpns_enable_fake_domain_blocking', false);
			update_site_option('mo_wpns_enable_advanced_user_verification', false);
			update_site_option('mo_wpns_enable_social_integration', false);
			update_site_option('mo2f_protect_wp_config', 0);
			update_site_option('mo2f_prevent_directory_browsing', 0);
			update_site_option('mo2f_disable_file_editing', 0);
			update_site_option('mo_wpns_enable_comment_spam_blocking', false);
			update_site_option('mo_wpns_enable_comment_recaptcha', false);
			update_site_option('mo2f_htaccess_file', 0);
			if(sanitize_text_field($_POST['option']) == 'tab_login_switch')
				do_action('mowaf_show_message',MOWAF_Messages::showMessage('LOGIN_DISABLE'),'ERROR');
		}
	}


	public function mowaf_handle_block_enable(){
		$nonce =sanitize_text_field ( $_POST['nonce']);
	   		if ( ! wp_verify_nonce( $nonce, 'mowaf-switch-functions-nonce' ) ){
		do_action('mowaf_show_message',MOWAF_Messages::showMessage('NONCE_ERROR'),'ERROR');
	   			return;
	   		}
		$POSTED = isset($_POST['switch_val']);
		$POSTED=sanitize_text_field($POSTED);
		if($POSTED){
			update_site_option('mo_2f_switch_adv_block', 1);
			update_site_option('mowaf_tab_count', get_site_option('mowaf_tab_count')+1);
			if(sanitize_text_field ($_POST['option']) == 'tab_block_switch')
				do_action('mowaf_show_message',MOWAF_Messages::showMessage('ADV_BLOCK_ENABLE'),'SUCCESS');
		}
		else{
			update_site_option('mo_2f_switch_adv_block', 0);
			update_site_option('mowaf_tab_count', get_site_option('mowaf_tab_count')-1);
			update_site_option('mo_wpns_iprange_count', 0);
			update_site_option('mo_wpns_enable_htaccess_blocking', 0);
			update_site_option('mo_wpns_enable_user_agent_blocking', 0);
			update_site_option('mo_wpns_referrers', false);
			update_site_option('mo_wpns_countrycodes', false);
			if(sanitize_text_field ($_POST['option']) == 'tab_block_switch')
				do_action('mowaf_show_message',MOWAF_Messages::showMessage('ADV_BLOCK_DISABLE'),'ERROR');
		}
	}

	public function mowaf_handle_report_enable(){
		$nonce = sanitize_text_field ($_POST['nonce']);
	   		if ( ! wp_verify_nonce( $nonce, 'mowaf-switch-functions-nonce' ) ){
		do_action('mowaf_show_message',MOWAF_Messages::showMessage('NONCE_ERROR'),'ERROR');
	   			return;
	   		}
		$POSTED = isset($_POST['switch_val']);
		$POSTED=sanitize_text_field($POSTED);
		if($POSTED){
			update_site_option('mo_2f_switch_reports', 1);
			update_site_option('mowaf_tab_count', get_site_option('mowaf_tab_count')+1);
			if(sanitize_text_field ($_POST['option']) == 'tab_report_switch')
				do_action('mowaf_show_message',MOWAF_Messages::showMessage('REPORT_ENABLE'),'SUCCESS');
		}
		else{
			update_site_option('mo_2f_switch_reports', 0);
			update_site_option('mowaf_tab_count', get_site_option('mowaf_tab_count')-1);
			if(sanitize_text_field ($_POST['option']) == 'tab_report_switch')
				do_action('mowaf_show_message',MOWAF_Messages::showMessage('REPORT_DISABLE'),'ERROR');
		}
	}

	public function mowaf_handle_notif_enable(){
		$nonce = sanitize_text_field ($_POST['nonce']);
	   		if ( ! wp_verify_nonce( $nonce, 'mowaf-switch-functions-nonce' ) ){
		do_action('mowaf_show_message',MOWAF_Messages::showMessage('NONCE_ERROR'),'ERROR');
	   			return;
	   		}
		$POSTED = isset($_POST['switch_val']);
		$POSTED=sanitize_text_field($POSTED);
		if($POSTED){
			update_site_option('mo_2f_switch_notif', 1);
			update_site_option('mowaf_tab_count', get_site_option('mowaf_tab_count')+1);
			if(sanitize_text_field ($_POST['option']) == 'tab_notif_switch')
				do_action('mowaf_show_message',MOWAF_Messages::showMessage('NOTIF_ENABLE'),'SUCCESS');
		}
		else{
			update_site_option('mo_2f_switch_notif', 0);
			update_site_option('mowaf_tab_count', get_site_option('mowaf_tab_count')-1);
			update_site_option('mo_wpns_enable_ip_blocked_email_to_admin', false);
			update_site_option('mo_wpns_enable_unusual_activity_email_to_user', false);
			if(sanitize_text_field ($_POST['option']) == 'tab_notif_switch')
				do_action('mowaf_show_message',MOWAF_Messages::showMessage('NOTIF_DISABLE'),'ERROR');
		}
	}

}
new MOWAF_ajax_dashboard();
?>