<?php
	
	global $mowafutility, $mowaf_dirname;


	if(current_user_can( 'manage_options' ) && isset($_POST['option']))
	{
		$option = sanitize_text_field ($_POST['option']);
		switch($option)
		{
			case "mowaf_enable_fake_domain_blocking":
				mowaf_handle_domain_blocking();						break;
			case "mowaf_advanced_user_verification":
				mowaf_handle_advanced_user_verification();			break;
			case "mowaf_social_integration":
				mowaf_handle_enable_social_login();					break;
			
		}
	}

	$otpVerify_url 	= add_query_arg( array('page' => 'mosettings', 'tab'=>'settings'), $_SERVER['REQUEST_URI'] );
	$openid_url 	= add_query_arg( array('page' => 'mo_openid_settings'			), $_SERVER['REQUEST_URI'] );
	$domain_blocking= get_site_option('mo_wpns_enable_fake_domain_blocking') 		? "checked" : "";
	$user_verify	= get_site_option('mo_wpns_enable_advanced_user_verification') 	? "checked" : "";	
	$social_login	= get_site_option('mo_wpns_enable_social_integration') 			? "checked" : "";

	if($user_verify)
	{
		$moOTPPlugin = new MOWAF_OTPPlugin();
		$status 	 = $moOTPPlugin->getstatus();
		switch ($status) 
		{
			case "ACTIVE":
				$html1 = "<br><a href='".esc_url($otpVerify_url)."'>Click here to configure.</a>";
				$moOTPPlugin->updatePluginConfiguration();
				break;
			case "INSTALLED":
				$path 		 = "miniorange-otp-verification/miniorange_validation_settings.php";
				$activateUrl = wp_nonce_url(admin_url('plugins.php?action=activate&plugin='.$path), 'activate-plugin_'.$path);
				$html1 		 = '<br><span style="color:red">For Advanced User Verification you need to have miniOrange OTP Verification plugin activated.</span><br><a href="'.esc_url($activateUrl).'">Click here to activate OTP Verification Plugin</a>';
				break;
			default:
				$action 	  = 'install-plugin';
				$slug 		  = 'miniorange-otp-verification';
				$install_link =  wp_nonce_url(
									add_query_arg( array( 'action' => $action, 'plugin' => $slug ), admin_url( 'update.php' ) ),
									$action.'_'.$slug
								);
				$html1 		  = '<br><span style="color:red">For Advanced User Verification you need to have miniOrange OTP Verification plugin installed.</span><br><a href="'.esc_url($install_link).'">Install OTP Verification plugin</a>';
				break;
		}
	}


	if($social_login)
	{
		$moSocialLogin = new MOWAF_SocialPlugin();
		$status		   = $moSocialLogin->getstatus();
		switch ($status) 
		{
			case "ACTIVE":
				$html2 			 = "<br><a href='".esc_url($openid_url)."'>Click here to configure.</a>";
				break;
			case "INSTALLED":
				$path 		 = "miniorange-login-openid/miniorange_openid_sso_settings.php";
				$activateUrl = wp_nonce_url(admin_url('plugins.php?action=activate&plugin='.$path), 'activate-plugin_'.$path);
				$html2 		 = '<br><span style="color:red">For Social Login Integration you need to have miniOrange Social Login, Sharing plugin activated.</span><br><a href="'.esc_url($activateUrl).'">Click here to activate Social Login, Sharing Plugin</a>';
				break;
			default:
				$action   	  = 'install-plugin';
				$slug 		  = 'miniorange-login-openid';
				$install_link =  wp_nonce_url(
									add_query_arg( array( 'action' => $action, 'plugin' => $slug ), admin_url( 'update.php' ) ),
									$action.'_'.$slug
								); 
				$html2 		  = '<br><span style="color:red">For Social Login Integration you need to have miniOrange Social Login, Sharing plugin installed.</span><br><a href="'.esc_url($install_link).'">Install Social Login, Sharing plugin</a>';
				break;
		}
	}

	include $mowaf_dirname . 'views'.DIRECTORY_SEPARATOR.'registration-security.php';

	function mowaf_handle_domain_blocking()
	{	
	   $nonce = sanitize_text_field($_POST['nonce']);
	   	if ( ! wp_verify_nonce( $nonce, 'registrationSecurityNonce' ) ){
		do_action('mowaf_show_message',MOWAF_Messages::showMessage('NONCE_ERROR'),'ERROR');
	   		return;
	   	}
		$enable_fake_emails = isset($_POST['mo_wpns_enable_fake_domain_blocking']) ? true : false;
		update_site_option( 'mo_wpns_enable_fake_domain_blocking', $enable_fake_emails);

		if($enable_fake_emails)
			do_action('mowaf_show_message',MOWAF_Messages::showMessage('DOMAIN_BLOCKING_ENABLED'),'SUCCESS');
		else
			do_action('mowaf_show_message',MOWAF_Messages::showMessage('DOMAIN_BLOCKING_DISABLED'),'ERROR');
	}

	function mowaf_handle_advanced_user_verification()
	{
		$nonce = sanitize_text_field($_POST['nonce']);
	   	if ( ! wp_verify_nonce( $nonce, 'registrationSecurityNonce' ) ){
		do_action('mowaf_show_message',MOWAF_Messages::showMessage('NONCE_ERROR'),'ERROR');
	   		return;
	   	}
		$enable_advanced_user_verification = isset($_POST['mo_wpns_enable_advanced_user_verification']) ? true : false;
		update_site_option( 'mo_wpns_enable_advanced_user_verification',  $enable_advanced_user_verification);

		if($enable_advanced_user_verification)
		{
			update_site_option('mo_customer_validation_wp_default_enable',1);
			do_action('mowaf_show_message',MOWAF_Messages::showMessage('ENABLE_ADVANCED_USER_VERIFY'),'SUCCESS');
		}
		else
		{
			update_site_option('mo_customer_validation_wp_default_enable',0);
			do_action('mowaf_show_message',MOWAF_Messages::showMessage('DISABLE_ADVANCED_USER_VERIFY'),'ERROR');
		}
	}

	function mowaf_handle_enable_social_login()
	{
		$nonce = sanitize_text_field($_POST['nonce']);
	   	if ( ! wp_verify_nonce( $nonce, 'registrationSecurityNonce' ) ){
		do_action('mowaf_show_message',MOWAF_Messages::showMessage('NONCE_ERROR'),'ERROR');
	   		return;
	   	}
		$social_login = isset($_POST['mo_wpns_enable_social_integration']) ? true : false;
		update_site_option( 'mo_wpns_enable_social_integration',  $social_login);

		if($social_login)
			do_action('mowaf_show_message',MOWAF_Messages::showMessage('ENABLE_SOCIAL_LOGIN'),'SUCCESS');
		else
			do_action('mowaf_show_message',MOWAF_Messages::showMessage('DISABLE_SOCIAL_LOGIN'),'ERROR');
	}