<?php
class MOWAF_Feedback_Handler
{
    function __construct()
    {
        add_action('admin_init', array($this, 'mowaf_feedback_actions'));
    }

    function mowaf_feedback_actions()
    {

        global $mowafutility, $mowaf_dirname;

        if (current_user_can('manage_options') && isset($_POST['option'])) {
            $option = sanitize_text_field($_REQUEST['option']);
            switch ($option) {
                case "mo_wpns_skip_feedback":              
                case "mo_wpns_feedback":                    
                  $this->wpns_handle_feedback();                     break;
            }
        }
    }


    function wpns_handle_feedback()
    {
        $nonce = sanitize_text_field($_POST['nonce']);
            if ( ! wp_verify_nonce( $nonce, 'mowaf-feedback-nonce' ) ){
        do_action('mowaf_show_message',MOWAF_Messages::showMessage('NONCE_ERROR'),'ERROR');
                return;
            }
        $user = wp_get_current_user();
        $feedback_option = sanitize_text_field($_POST['option']);
        $message = 'Plugin Deactivated';

        $deactivate_reason_message = array_key_exists('wpns_query_feedback', $_POST) ? sanitize_text_field($_POST['wpns_query_feedback']) : false;


        $reply_required = '';
        if (isset($_POST['get_reply']))
            $reply_required = sanitize_text_field($_POST['get_reply']);
        if (empty($reply_required)) {
            $reply_required = "don't reply";
            $message .= '<b style="color:red";> &nbsp; [Reply :' . $reply_required . ']</b>';
        } else {
            $reply_required = "yes";
            $message .= '[Reply :' . $reply_required . ']';
        }


        $message .= ', Feedback : ' . $deactivate_reason_message . '';

        if (isset($_POST['rate']))
            $rate_value = sanitize_text_field($_POST['rate']);
		else
			$rate_value = "--";
        $message .= ', [Rating :' . $rate_value . ']';

        $email = isset($_POST['query_mail'])? sanitize_email($_POST['query_mail']): '';
        if (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
            $email = get_site_option('mo2f_email');
            if (empty($email))
                $email = $user->user_email;
        }
        $phone = get_site_option('mo_wpns_admin_phone');
        $feedback_reasons = new MOWAF_cURL();
        global $mowafutility,$mowaf_dirname;
        if (!is_null($feedback_reasons)) {
            if (!$mowafutility->is_curl_installed()) {
                deactivate_plugins($mowaf_dirname."\\miniorange_firewall_settings.php");
                wp_redirect('plugins.php');
            } else {
                $submited = json_decode($feedback_reasons->send_email_alert($email, $phone, $message, $feedback_option), true);
                if (json_last_error() == JSON_ERROR_NONE) {
                    if (is_array($submited) && array_key_exists('status', $submited) && $submited['status'] == 'ERROR') {
                        do_action('mowaf_show_message',$submited['message'],'ERROR');

                    } else {
                        if ($submited == false) {
                            do_action('mowaf_show_message','Error while submitting the query.','ERROR');
                        }
                    }
                }

                deactivate_plugins($mowaf_dirname."\\miniorange_firewall_settings.php");
                do_action('mowaf_show_message','Thank you for the feedback.','SUCCESS');

            }
        }
    }

}new MOWAF_Feedback_Handler();
