<?php 
include 'class_mowaf_strong_password.php';
	class MOWAF_LoginHandler
	{
		function __construct()
		{
			add_action( 'init' , array( $this, 'mo_wpns_init' ) );
			if(get_site_option('mo2f_restrict_restAPI')){
				add_action('rest_api_init' , array($this , 'mo_block_restAPI' ) );
			}
			$mowaf_ns_config = new MOWAF_Utility();

			$mowaf_strong_password = new MOWAF_strong_password();
		
			if($mowaf_ns_config->hasLoginCookie()){
				add_action('user_profile_update_errors', array( $mowaf_strong_password, 'validatePassword'), 0, 3 );
				add_action( 'woocommerce_save_account_details_errors', array( $mowaf_strong_password, 'woocommerce_password_edit_account' ),1,2 );
			}
				add_filter( 'woocommerce_process_registration_errors', array($mowaf_strong_password,'woocommerce_password_protection'),1,4);
				add_filter( 'woocommerce_registration_errors', array($mowaf_strong_password,'woocommerce_password_registration_protection'),1,3);
			
			if(get_site_option('mo2f_enforce_strong_passswords') || get_site_option('mo_wpns_activate_recaptcha_for_login') 
				|| get_site_option('mo_wpns_activate_recaptcha_for_woocommerce_login'))
			{

				remove_filter('authenticate'		 , 'wp_authenticate_username_password'				 ,20 );
				add_filter   ('authenticate'		 , array( $this, 'custom_authenticate'		       ) ,1, 3 );
			} 
			
				add_action('wp_login'				 , array( $this, 'mo_wpns_login_success' 	       )		);
				add_action('wp_login_failed'		 , array( $this, 'mo_wpns_login_failed'	 	       ) 	    );
		
                        if(get_site_option('mo_wpns_activate_recaptcha_for_woocommerce_registration') ){
				add_action( 'woocommerce_register_post', array( $this,'wooc_validate_user_captcha_register'), 1, 3);
			} 
		}	

		function mo_block_restAPI(){
			global $mowafutility,$mowaf_dirname;
			if(strpos($_SERVER['REQUEST_URI'], '/wp-json/wp/v2/users')){
				include $mowaf_dirname . 'views'.DIRECTORY_SEPARATOR.'error'.DIRECTORY_SEPARATOR.'403.php';
			}
		}

		function mo_wpns_init()
		{
			
			global $mowafutility,$mowaf_dirname;
			$WAFEnabled = get_site_option('WAFEnabled');
			$WAFLevel = get_site_option('WAF');

			if($WAFEnabled == 1)
			{
				if($WAFLevel == 'PluginLevel')
				{
					if(file_exists($mowaf_dirname .'handler'.DIRECTORY_SEPARATOR.'WAF'.DIRECTORY_SEPARATOR.'mo-waf-plugin.php'))
						include_once($mowaf_dirname .'handler'.DIRECTORY_SEPARATOR.'WAF'.DIRECTORY_SEPARATOR.'mo-waf-plugin.php');
				}
			}
			
			$userIp 			= $mowafutility->get_client_ip();
			$mowaf_config       = new MOWAF_Handler();
			$isWhitelisted      = $mowaf_config->is_whitelisted($userIp);
			$isIpBlocked        = false;
			if(!$isWhitelisted){
			$isIpBlocked = $mowaf_config->is_ip_blocked_in_anyway($userIp);
			}
			if($isIpBlocked)
			include $mowaf_dirname . 'views'.DIRECTORY_SEPARATOR.'error'.DIRECTORY_SEPARATOR.'403.php';


			$requested_uri = $_SERVER["REQUEST_URI"];
			$option = false;
			if (is_user_logged_in()) {
				if (strpos($requested_uri, chr(get_site_option('login_page_url'))) != false) {
					wp_redirect(site_url());
					die;
				}
			} else {
				$option = get_site_option('mo_wpns_enable_rename_login_url');
			}
			if ($option) {
                if (strpos($requested_uri, '/wp-login.php?checkemail=confirm') !== false) {
                    $requested_uri = str_replace("wp-login.php","",$requested_uri);
                    wp_redirect($requested_uri);
                    die;
                } else if (strpos($requested_uri, '/wp-login.php?checkemail=registered') !== false) {
                    $requested_uri = str_replace("wp-login.php","",$requested_uri);
                    wp_redirect($requested_uri);
                    die;
                }
                
                if (strpos($requested_uri, '/wp-login.php') !== false) {
					wp_redirect(site_url());
				}
				else if (strpos($requested_uri, get_site_option('login_page_url')) !== false ) {
					@require_once ABSPATH . 'wp-login.php';
					die;
				}
			}
			
			if(isset($_POST['option']))
			{
					switch(sanitize_text_field($_POST['option']))
					{
						case "mo_wpns_change_password":
							$this->handle_change_password(sanitize_text_field($_POST['username'])
								,sanitize_text_field($_POST['new_password']),sanitize_text_field($_POST['confirm_password']));		
							break;
					}
			}

		}

		function wooc_validate_user_captcha_register($username, $email, $validation_errors) {
			
			if (empty($_POST['g-recaptcha-response'])) {
				$validation_errors->add( 'woocommerce_recaptcha_error', __('Please verify the captcha', 'woocommerce' ) );
			}
		}

		function handle_change_password($username,$newpassword,$confirmpassword)
		{
			$nonce = sanitize_text_field ($_POST['nonce']);
	   		if ( ! wp_verify_nonce( $nonce, 'mowaf-change-password-nonce' ) ){
				return 'error';
	   		}
			global $mowaf_dirname;
			$user  = get_user_by("login",$username);
			$error = wp_authenticate_username_password($user,$username,$newpassword);
			
			if(is_wp_error($error))
			{
				$this->mo_wpns_login_failed($username);
				return $error;
			}

			if($this->update_strong_password($username,$newpassword,$confirmpassword)=="success")
			{
				wp_set_auth_cookie($user->ID,false,false);
				$this->mo_wpns_login_success($username);
				wp_redirect(get_site_option('siteurl'),301);
			} 
		}

		function update_strong_password($username,$newpassword,$confirmpassword)
		{
			global $mowaf_dirname;
			
			if(strlen($newpassword) > 5 && preg_match("#[0-9]+#", $newpassword) && preg_match("#[a-zA-Z]+#", $newpassword) 
				&& preg_match('/[^a-zA-Z\d]/', $newpassword) && $newpassword==$confirmpassword)
			{
				$user = get_user_by("login",$username);
				wp_set_password(sanitize_text_field($_POST['new_password']),$user->ID);
				return "success";
			} 
			else
				include $mowaf_dirname . 'controllers'.DIRECTORY_SEPARATOR.'change-password.php';
		}

		function custom_authenticate($user, $username, $password)
		{
			global $mowafutility;
			$error = new WP_Error();

			if(empty($username) && empty ($password))
				return $error;

			if(empty($username)) {
                $error->add('empty_username', __('<strong>ERROR</strong>: Invalid username or Password.'));
			}
			if(empty($password)) {
                $error->add('empty_password', __('<strong>ERROR</strong>: Invalid username or Password.'));
            }

            $user = wp_authenticate_username_password( $user, $username, $password );

			if ( is_wp_error( $user ) ) {
                $error->add('empty_username', __('<strong>ERROR</strong>: Invalid username or Password.'));
                return $user;
            }
            if(empty($error->errors))
			{
				$user  = get_user_by("login",$username);

				if($user)
				{
					if(get_site_option('mo_wpns_activate_recaptcha_for_login'))
						$recaptchaError = $mowafutility->verify_recaptcha(sanitize_text_field($_POST['g-recaptcha-response']));

					if(!empty($recaptchaError->errors))
						$error = $recaptchaError;
 					if(empty($error->errors)){
						if(!get_site_option('mo2f_enable_brute_force'))
						{
						   $this->mo_wpns_login_success($username);
						}
						return $user;
					}
				}
				else
					$error->add('empty_password', __('<strong>ERROR</strong>: Invalid Username or password.'));

			}

			return $error;
		}

		function mo_wpns_login_success($username)
		{
			global $mowafutility;

				$mowaf_config = new MOWAF_Handler();
				$userIp 		= $mowafutility->get_client_ip();

				$mowaf_config->move_failed_transactions_to_past_failed($userIp);

				if(get_site_option('mo_wpns_enable_unusual_activity_email_to_user'))
					$mowafutility->sendNotificationToUserForUnusualActivities($username, $userIp, MOWAF_Constants::LOGGED_IN_FROM_NEW_IP);


				$mowaf_config->add_transactions($userIp, $username, MOWAF_Constants::LOGIN_TRANSACTION, MOWAF_Constants::SUCCESS);
				
				if(isset($_POST['log']) && isset($_POST['pwd'])){
				$username =  sanitize_text_field($_POST['log']);
				$pass = sanitize_text_field($_POST['pwd']);
				$user = get_user_by('login',$username);
						
				if(!get_site_option('mo2f_enforce_strong_passswords')){
					if(!MOWAF_strong_password::mo2f_isStrongPasswd($pass, $username)){
						if(!get_user_meta($user->ID,'password_strong?')){
							update_user_meta($user->ID,'password_strong?', true);
							$count = get_site_option('users_with_weak_pass');
							$count = $count + 1;
							update_site_option('users_with_weak_pass', $count);
						}
					}
					else{
						if(get_user_meta($user->ID,'password_strong?')){
							$count = get_site_option('users_with_weak_pass');
							$count = $count - 1;
						update_site_option('users_with_weak_pass', $count);
						}
						delete_user_meta($user->ID,'password_strong?');
					}
					

				}

			}
		}

		function mo_wpns_login_failed($username)
		{
			global $mowafutility;
				$userIp 		= $mowafutility->get_client_ip();
			
				if(empty($userIp) || empty($username))
					return;

				$mowaf_config = new MOWAF_Handler();
				$isWhitelisted  = $mowaf_config->is_whitelisted($userIp);
					
				$mowaf_config->add_transactions($userIp, $username, MOWAF_Constants::LOGIN_TRANSACTION, MOWAF_Constants::FAILED);

				if(!$isWhitelisted && get_site_option('mo2f_enable_brute_force') )
				{
					

					if(get_site_option('mo_wpns_enable_unusual_activity_email_to_user'))
							$mowafutility->sendNotificationToUserForUnusualActivities($username, $userIp, MOWAF_Constants::FAILED_LOGIN_ATTEMPTS_FROM_NEW_IP);
					
					$failedAttempts 	 = $mowaf_config->get_failed_attempts_count($userIp);
					$allowedLoginAttepts = get_site_option('mo2f_allwed_login_attempts') ? get_site_option('mo2f_allwed_login_attempts') : 10;
						
					if($allowedLoginAttepts - $failedAttempts<=0)
						$this->handle_login_attempt_exceeded($userIp);
					else if(get_site_option('mo2f_show_remaining_attempts')) 
						$this->show_limit_login_left($allowedLoginAttepts,$failedAttempts);
				}
			
		}

		function show_limit_login_left($allowedLoginAttepts,$failedAttempts)
		{
			global $error;
			$diff = $allowedLoginAttepts - $failedAttempts;
			$error = "<br>You have <b>".esc_html($diff)."</b> login attempts remaining.";
		}

		function handle_login_attempt_exceeded($userIp)
		{
			global $mowafutility, $mowaf_dirname;
			$mowaf_config = new MOWAF_Handler();
			$mowaf_config->block_ip($userIp, MOWAF_Constants::LOGIN_ATTEMPTS_EXCEEDED, false);
			include $mowaf_dirname . 'views'.DIRECTORY_SEPARATOR.'error'.DIRECTORY_SEPARATOR.'403.php';
		}

	}
	new MOWAF_LoginHandler;
